@@ -121,9 +121,8 @@ def get_logger(level='info', logfile=None, logfilemode='a',
         print(" + Error, unknown logging mode {}, please choose: short/long/manual".format(loggingmode))
     
     # reseting current logger config 
-    logging.shutdown()
-    reload(logging)
-
+    logging.handlers = []
+    
     formatter = ColoredFormatter(format_str,style='{', datefmt=format_date,colors=colors)
     handler = logging.StreamHandler(sys.stdout)
     handler.setFormatter(formatter)
@@ -154,9 +153,9 @@ def get_logger(level='info', logfile=None, logfilemode='a',
                         logger_config['formatters'][k]['format'] = "%(color)s"+current_format
                 
             config.dictConfig(logger_config)
-        init() # for windows support 
         os.system("cls" or "clear") # for windows support 
     except: 
         pass
 
-    return logging
\ No newline at end of file
+    return logger
+
